@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate.py 10302 2017-09-17 10:06:27Z Lavender $
+# $Id: build_boilerplate.py 10303 2017-09-17 10:33:08Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-09-17 18:06:27 +0800 (週日, 17 九月 2017) $
-# $Revision: 10302 $
+# $Date: 2017-09-17 18:33:08 +0800 (週日, 17 九月 2017) $
+# $Revision: 10303 $
 
 import os
 import sys
@@ -28,9 +28,9 @@ from django.template.loader import get_template
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import cerateLogger
+from Zephyrus.boilerplate.management.commands import createLogger
 
-logger = cerateLogger(__name__, "BuildBoilerplate.log")
+logger = createLogger(__name__, "BuildBoilerplate.log")
 
 # inside
 TEXT_TAGS = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'button',]
