@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_pages.py 10200 2017-08-20 02:49:07Z Lavender $
+# $Id: create_pages.py 10213 2017-08-22 09:34:20Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
-# $Revision: 10200 $
+# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
+# $Revision: 10213 $
 
 import os
 import json
@@ -26,9 +26,9 @@ from cms.models.titlemodels import Title
 
 from Zephyrus.boilerplate.management.commands import (
         TEMPLATES_DIR_PATH, ROOT_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import cerateLogger
+from Zephyrus.boilerplate.management.commands import createLogger
 
-logger = cerateLogger(__name__, "CreatePages.log")
+logger = createLogger(__name__, "CreatePages.log")
 
 class Command(BaseCommand):
 
