@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10330 2017-10-01 01:54:54Z Lavender $
+# $Id: create_zip.py 10341 2017-10-03 08:42:24Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-01 09:54:54 +0800 (週日, 01 十月 2017) $
-# $Revision: 10330 $
+# $Date: 2017-10-03 16:42:24 +0800 (週二, 03 十月 2017) $
+# $Revision: 10341 $
 
 import os
 import shutil
@@ -41,6 +41,11 @@ class Command(BaseCommand):
             '-o', '--onlyTemplate', 
             action='store_true',
             help="Only output template zip. Not have template shop info")
+            
+        parser.add_argument(
+            '-n', '--templateName', 
+            type=str, default='template',
+            help="Use the name to create template zip name.")
 
     def handle(self, *args, **options):
         if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
@@ -57,9 +62,11 @@ class Command(BaseCommand):
             with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
                 line = json.dumps(data)
                 f.write(line)
+                
+        templateName = options['templateName']
 
         zip = zipfile.ZipFile(
-            os.path.join(ROOT_DIR_PATH, 'template.zip'), mode='w')
+            os.path.join(ROOT_DIR_PATH, '%s.zip' % templateName), mode='w')
 
         logger.info("-----Start copy templates-----")
         for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
@@ -119,10 +126,12 @@ class Command(BaseCommand):
                     logger.info("Zip " + path)
                     zip.write(path)
                     
-            zip.write('template.zip')
+            zip.write('%s.zip' % templateName)
             zip.close()
         else:      
-            shutil.copyfile('./template.zip', os.path.join(dst, 'template.zip'))
+            shutil.copyfile(
+                './%s.zip' % templateName, 
+                os.path.join(dst, '%s.zip' % templateName))
         
         if os.path.exists(FIXTURES_DIR_PATH):
             shutil.rmtree(FIXTURES_DIR_PATH)
@@ -134,7 +143,7 @@ class Command(BaseCommand):
             os.remove('./setup.py')
         if os.path.isfile('./info.json'):
             os.remove('./info.json')
-        if os.path.isfile('./template.zip'):
-            os.remove('./template.zip')
+        if os.path.isfile('./%s.zip' % templateName):
+            os.remove('./%s.zip' % templateName)
         
         logger.info('-----All OK!-----')
\ No newline at end of file
