@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 10213 2017-08-22 09:34:20Z Lavender $
+# $Id: fix_template.py 10330 2017-10-01 01:54:54Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
-# $Revision: 10213 $
+# $Date: 2017-10-01 09:54:54 +0800 (週日, 01 十月 2017) $
+# $Revision: 10330 $
 
 import os
 import shutil
@@ -57,7 +57,7 @@ class Command(BaseCommand):
                 "{% render_block 'css' %}").hexdigest()
             toolbarHash = "%s" % hashlib.md5(
                 "{% cms_toolbar %}").hexdigest()
-            with open(file, 'r') as f:
+            with open(file, 'rb') as f:
                 text = f.read()
                 text = text.replace(
                     "{% load cms_tags menu_tags sekizai_tags %}"
@@ -92,7 +92,7 @@ class Command(BaseCommand):
             text = text.replace(jsHash, "{% render_block 'js' %}")
             text = text.replace(cssHash, "{% render_block 'css' %}")
             text = text.replace(toolbarHash, "{% cms_toolbar %}")
-            with open(fileName, 'w') as f:
-                f.write(text)
+            with open(fileName, 'wb') as f:
+                f.write(text.encode('utf8'))
             
         
\ No newline at end of file
