@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10332 2017-10-01 02:54:19Z Lavender $
+# $Id: setup.py 10347 2017-10-03 09:43:25Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-01 10:54:19 +0800 (週日, 01 十月 2017) $
-# $Revision: 10332 $ 
+# $Date: 2017-10-03 17:43:25 +0800 (週二, 03 十月 2017) $
+# $Revision: 10347 $ 
 
 import os
 import sys
@@ -250,12 +250,30 @@ if __name__ == "__main__":
     
     import django
     
-    if not (django.VERSION[0] == 1 and django.VERSION[1] <= 10):
-        logger.error(
-            "Your installed Django above 1.10 which is not supported by "
-            "Django CMS 3.4 yet, please reinstall Django or you may encounter "
-            "some issues while using Django CMS.")
-        sys.exit()
+    try:
+        import cms
+    except Exception as e:
+        os.system("pip install django-cms")
+        import cms
+        
+    cmsVersion = cms.__version__.split('.')
+    
+    cms34 = True
+    try:
+        if int(cmsVersion[0]) <= 3 and int(cmsVersion[1]) <= 4:
+            cms34 = True
+        else:
+            cms34 = False
+    except Exception as e:
+        cms34 = False
+        
+    if cms34:
+        if not (django.VERSION[0] == 1 and django.VERSION[1] <= 10):
+            logger.error(
+                "Your installed Django above 1.10 which is not supported by "
+                "Django CMS 3.4 yet, please reinstall Django or you may "
+                "encounter some issues while using Django CMS.")
+            sys.exit()
     django.setup()
     
     from django.conf import settings
