@@ -37,7 +37,14 @@ class AdminPlaceholderTag(Tag):
     
     def render_tag(self, context, name, extra_bits, nodelist=None):
         page = context['current_page']
+        fromUrl = context['request'].path_info
         
+        globalObj, created = AdminPlaceholder.objects.get_or_create(
+                name=name,
+                fromUrl=None,
+                defaults={'text': '', 'page': None,},
+            )
+            
         if nodelist:
             text = nodelist.render(context)
         else:
@@ -45,21 +52,18 @@ class AdminPlaceholderTag(Tag):
             
         obj, created = AdminPlaceholder.objects.get_or_create(
             name=name,
-            page=page,
-            defaults={'text': text,},
+            fromUrl=fromUrl,
+            defaults={'text': text, 'page': page,},
         )
         
         if obj.useGlobalAdminPlaceholder:
-            obj, created = AdminPlaceholder.objects.get_or_create(
-                name=name,
-                page=None,
-                defaults={'text': '',},
-            )
+            obj = globalObj
         
         return obj.text
         
 class BlockDisplayControlTag(Tag):
     name = 'blockDisplayControlTag'
+
     options = Options(
         Argument('name'),
         blocks=[('endBlockDisplayControl', 'nodelist')],
@@ -67,16 +71,22 @@ class BlockDisplayControlTag(Tag):
 
     def render_tag(self, context, name, nodelist):
         page = context['current_page']
+        fromUrl = context['request'].path_info
+        
+        globalObj, created = BlockDisplayControl.objects.get_or_create(
+                name=name,
+                fromUrl=None,
+                defaults={'page': None,},
+            )
+        
         obj, created = BlockDisplayControl.objects.get_or_create(
             name=name,
-            page=page,
+            fromUrl=fromUrl,
+            defaults={'page': page,},
         )
         
         if obj.useGlobalBlockDisplayControl:
-            obj, created = BlockDisplayControl.objects.get_or_create(
-                name=name,
-                page=None,
-            )
+            obj = globalObj
         
         if obj.display:
             text = nodelist.render(context)
