@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 9869 2017-04-16 09:42:35Z Lavender $
+# $Id: urls.py 9895 2017-04-23 04:33:47Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,10 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-16 17:42:35 +0800 (週日, 16 四月 2017) $
-# $Revision: 9869 $ 
+# $Date: 2017-04-23 12:33:47 +0800 (週日, 23 四月 2017) $
+# $Revision: 9895 $ 
 
-from django.conf.urls import url, include
+from django.conf.urls import url
 
 from . import views
 
@@ -23,6 +23,6 @@ app_name = 'landing'
 
 urlpatterns = [
     url(r'^email$', views.EmailView.as_view(), name='landing_email'),
-    url(r'^landingsocial$', views.LandingSocialView.as_view(), 
+    url(r'^landing_social$', views.LandingSocialView.as_view(), 
         name='landing_social'),
 ]
