@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10236 2017-08-29 09:07:40Z Lavender $
+# $Id: views.py 10323 2017-09-26 10:41:04Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-29 17:07:40 +0800 (週二, 29 八月 2017) $
-# $Revision: 10236 $
+# $Date: 2017-09-26 18:41:04 +0800 (週二, 26 九月 2017) $
+# $Revision: 10323 $
 
 import datetime
 import logging
@@ -43,14 +43,13 @@ logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler())
 
-def sendAndRedirect(request, email, fromUrl, redirectTo):
+def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
     errorCode = ErrorCode.NORMAL
     
     # Deal with Form Plugin
     if 'form_id' in request.POST:
         formId = hashid_to_int(request.POST.get('form_id'))
         landingForm = get_object_or_404(FormDefinition, pk=formId)
-        
         form = FormBuilder(landingForm, data=request.POST, files=request.FILES)
         if not form.is_valid():
             return
@@ -65,10 +64,15 @@ def sendAndRedirect(request, email, fromUrl, redirectTo):
             key = slugify(field.label)
             value = form.cleaned_data.get(key, '(no input)')
             dataDict[key] = {'value': value, 'field': field,}
+    elif formId:
+        formId = hashid_to_int(formId)
+        landingForm = get_object_or_404(FormDefinition, pk=formId)
+        dataDict = {}
+        form = True
     else:
        landingForm = None
        form = None
-    
+   
     try:
         validate_email(email)
 
@@ -200,5 +204,7 @@ class LandingSocialView(View):
         email = user.email
         fromUrl = request.GET.get('fromUrl')
         redirectTo = request.GET.get('redirectTo')
+        formId = request.GET.get('formId')
         auth.logout(request)
-        return sendAndRedirect(request, email, fromUrl, redirectTo)
\ No newline at end of file
+        return sendAndRedirect(
+            request, email, fromUrl, redirectTo, formId=formId)
\ No newline at end of file
