@@ -120,6 +120,27 @@ class BuildBoilerplateTest(unittest.TestCase):
         self.getTestStatic('TestStatic')
         self.runBuildBoilerplate('Static.html', 'StaticAnswer.html')
 
+    def testDb(self):
+        self.reset()
+        self.getTestStatic('Demo')
+        self.runBuildBoilerplate('Demo.html', 'DemoAnswer.html', 
+                                 dst=TEMPLATES_DIR_PATH, delete=False, 
+                                 rename='index.html')
+        os.system("%s Manage.py create_pages" % sys.executable)
+        os.system("%s Manage.py pluginize" % sys.executable)
+        
+        import sqlite3
+        conn = sqlite3.connect('Zephyrus.db')
+        c = conn.cursor()
+        c.execute("SELECT COUNT(id) FROM cms_placeholder")
+        placeholderCount = c.fetchall()[0][0]
+
+        c.execute("SELECT COUNT(id) FROM cms_cmsplugin")
+        pluginCount = c.fetchall()[0][0]
+        c.close()
+        self.assertEqual(placeholderCount, pluginCount)
+        
+    
     # Z只是要讓這個函數最後跑
     def testZAttr(self):
         self.reset()
@@ -138,5 +159,6 @@ class BuildBoilerplateTest(unittest.TestCase):
         self.assertEqual(js1, js2)
         self.reset()
     
+    
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
